<?php

namespace Litecms\PaymentSetting\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\PaymentSetting\Http\Requests\PaymentSettingRequest;
use Litecms\PaymentSetting\Interfaces\PaymentSettingRepositoryInterface;
use Litecms\PaymentSetting\Models\PaymentSetting;

/**
 * Resource controller class for payment_setting.
 */
class PaymentSettingResourceController extends BaseController
{

    /**
     * Initialize payment_setting resource controller.
     *
     * @param type PaymentSettingRepositoryInterface $payment_setting
     *
     * @return null
     */
    public function __construct(PaymentSettingRepositoryInterface $payment_setting)
    {
        parent::__construct();
        $this->repository = $payment_setting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\PaymentSetting\Repositories\Criteria\PaymentSettingResourceCriteria::class);
    }

    /**
     * Display a list of payment_setting.
     *
     * @return Response
     */
    public function index(PaymentSettingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\PaymentSetting\Repositories\Presenter\PaymentSettingPresenter::class)
                ->$function();
        }

        $payment_settings = $this->repository->paginate();

        return $this->response->title(trans('payment_setting::payment_setting.names'))
            ->view('payment_setting::payment_setting.index', true)
            ->data(compact('payment_settings', 'view'))
            ->output();
    }

    /**
     * Display payment_setting.
     *
     * @param Request $request
     * @param Model   $payment_setting
     *
     * @return Response
     */
    public function show(PaymentSettingRequest $request, PaymentSetting $payment_setting)
    {

        if ($payment_setting->exists) {
            $view = 'payment_setting::payment_setting.show';
        } else {
            $view = 'payment_setting::payment_setting.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('payment_setting::payment_setting.name'))
            ->data(compact('payment_setting'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new payment_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PaymentSettingRequest $request)
    {

        $payment_setting = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('payment_setting::payment_setting.name')) 
            ->view('payment_setting::payment_setting.create', true) 
            ->data(compact('payment_setting'))
            ->output();
    }

    /**
     * Create new payment_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PaymentSettingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $payment_setting                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('payment_setting::payment_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('payment_setting/payment_setting/' . $payment_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/payment_setting/payment_setting'))
                ->redirect();
        }

    }

    /**
     * Show payment_setting for editing.
     *
     * @param Request $request
     * @param Model   $payment_setting
     *
     * @return Response
     */
    public function edit(PaymentSettingRequest $request, PaymentSetting $payment_setting)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('payment_setting::payment_setting.name'))
            ->view('payment_setting::payment_setting.edit', true)
            ->data(compact('payment_setting'))
            ->output();
    }

    /**
     * Update the payment_setting.
     *
     * @param Request $request
     * @param Model   $payment_setting
     *
     * @return Response
     */
    public function update(PaymentSettingRequest $request, PaymentSetting $payment_setting)
    {
        try {
            $attributes = $request->all();

            $payment_setting->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('payment_setting::payment_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('payment_setting/payment_setting/' . $payment_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('payment_setting/payment_setting/' . $payment_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the payment_setting.
     *
     * @param Model   $payment_setting
     *
     * @return Response
     */
    public function destroy(PaymentSettingRequest $request, PaymentSetting $payment_setting)
    {
        try {

            $payment_setting->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('payment_setting::payment_setting.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('payment_setting/payment_setting/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('payment_setting/payment_setting/' . $payment_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple payment_setting.
     *
     * @param Model   $payment_setting
     *
     * @return Response
     */
    public function delete(PaymentSettingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('payment_setting::payment_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('payment_setting/payment_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/payment_setting/payment_setting'))
                ->redirect();
        }

    }

    /**
     * Restore deleted payment_settings.
     *
     * @param Model   $payment_setting
     *
     * @return Response
     */
    public function restore(PaymentSettingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('payment_setting::payment_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/payment_setting/payment_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/payment_setting/payment_setting/'))
                ->redirect();
        }

    }

}
